@@ -101,6 +101,20 @@ default_role = 'any'
 
 # HTML theme
 html_theme = 'furo'
+html_logo = "images/logo.png"
+html_favicon = "images/favicon.ico"
+
+html_theme_options = {
+    "sidebar_hide_name": True,
+    "light_css_variables": {
+        "color-brand-primary": "#336790",  # "blue"
+        "color-brand-content": "#336790",
+    },
+    "dark_css_variables": {
+        "color-brand-primary": "#E5B62F",  # "yellow"
+        "color-brand-content": "#E5B62F",
+    },
+}
 
 # Add support for inline tabs
 extensions += ['sphinx_inline_tabs']
@@ -157,3 +171,5 @@ towncrier_draft_working_directory = '..'
 towncrier_draft_include_empty = False
 
 extensions += ['jaraco.tidelift']
+
+intersphinx_mapping['pip'] = 'https://pip.pypa.io/en/latest', None
